Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExperimentExpansion ¶
type ExperimentExpansion interface{}
type ExperimentInterface ¶
type ExperimentInterface interface {
Create(*v1alpha1.Experiment) (*v1alpha1.Experiment, error)
Update(*v1alpha1.Experiment) (*v1alpha1.Experiment, error)
UpdateStatus(*v1alpha1.Experiment) (*v1alpha1.Experiment, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Experiment, error)
List(opts v1.ListOptions) (*v1alpha1.ExperimentList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Experiment, err error)
ExperimentExpansion
}
ExperimentInterface has methods to work with Experiment resources.
type ExperimentsGetter ¶
type ExperimentsGetter interface {
Experiments(namespace string) ExperimentInterface
}
ExperimentsGetter has a method to return a ExperimentInterface. A group's client should implement this interface.
type RedskyopsV1alpha1Client ¶ added in v1.4.0
type RedskyopsV1alpha1Client struct {
// contains filtered or unexported fields
}
RedskyopsV1alpha1Client is used to interact with features provided by the redskyops.dev group.
func New ¶
func New(c rest.Interface) *RedskyopsV1alpha1Client
New creates a new RedskyopsV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*RedskyopsV1alpha1Client, error)
NewForConfig creates a new RedskyopsV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *RedskyopsV1alpha1Client
NewForConfigOrDie creates a new RedskyopsV1alpha1Client for the given config and panics if there is an error in the config.
func (*RedskyopsV1alpha1Client) Experiments ¶ added in v1.4.0
func (c *RedskyopsV1alpha1Client) Experiments(namespace string) ExperimentInterface
func (*RedskyopsV1alpha1Client) RESTClient ¶ added in v1.4.0
func (c *RedskyopsV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*RedskyopsV1alpha1Client) Trials ¶ added in v1.4.0
func (c *RedskyopsV1alpha1Client) Trials(namespace string) TrialInterface
type RedskyopsV1alpha1Interface ¶ added in v1.4.0
type RedskyopsV1alpha1Interface interface {
RESTClient() rest.Interface
ExperimentsGetter
TrialsGetter
}
type TrialExpansion ¶
type TrialExpansion interface{}
type TrialInterface ¶
type TrialInterface interface {
Create(*v1alpha1.Trial) (*v1alpha1.Trial, error)
Update(*v1alpha1.Trial) (*v1alpha1.Trial, error)
UpdateStatus(*v1alpha1.Trial) (*v1alpha1.Trial, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Trial, error)
List(opts v1.ListOptions) (*v1alpha1.TrialList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Trial, err error)
TrialExpansion
}
TrialInterface has methods to work with Trial resources.
type TrialsGetter ¶
type TrialsGetter interface {
Trials(namespace string) TrialInterface
}
TrialsGetter has a method to return a TrialInterface. A group's client should implement this interface.